@@ -91,8 +91,7 @@ class TestTypeHints(unittest.TestCase):
             rf.DataFrame(1)
 
     def test_eq_bad_rhs_object(self):
-        with self.assertRaisesRegex(TypeError, "must be DataFrame"):
-            self.df == 1
+        self.assertFalse(self.df == 1)
 
     def test_getitem_bad_key(self):
         pass
@@ -103,11 +102,11 @@ class TestTypeHints(unittest.TestCase):
 
     def test_combine_bad_columns(self):
         with self.assertRaisesRegex(TypeError, "must be list"):
-            self.df.combine(1, "foo")
+            self.df.combine(1, "foo", sep="-")
 
     def test_combine_bad_into_column(self):
         with self.assertRaisesRegex(TypeError, "must be str"):
-            self.df.combine(["foo", "bar"], 1)
+            self.df.combine(["foo", "bar"], 1, sep="-")
 
     def test_combine_bad_sep_argument(self):
         with self.assertRaisesRegex(TypeError, "must be str"):
@@ -176,10 +175,10 @@ class TestTypeHints(unittest.TestCase):
 
     def test_join_bad_how_argument(self):
         rhs = rf.DataFrame()
-        with self.assertRaisesRegex(
-            ValueError,
-            "method argument is invalid, must be one of {'left', 'right', 'inner', 'full'}",
-        ):
+        message = (
+            "on argument is invalid, must be one of {'left', 'right', 'inner', 'full'}"
+        )
+        with self.assertRaisesRegex(ValueError, message):
             self.df.join(rhs, on="baz", how="inside")
 
     def test_mutate_bad_over(self):
